# A Neural Population Mechanism for Rapid Learning

Publication(s): 
- Perich MG, Gallego JA, Miller LE. A Neural Population Mechanism for Rapid Learning. Neuron. 2018 Nov 21;100(4):964-976.e7. doi: 10.1016/j.neuron.2018.09.030. Epub 2018 Oct 18. PMID: 30344047; PMCID: PMC6250582.
- Perich MG, Miller LE. Altered tuning in primary motor cortex does not account for behavioral adaptation during force field learning. Exp Brain Res. 2017 Sep;235(9):2689-2704. doi: 10.1007/s00221-017-4997-1å. Epub 2017 Jun 6. PMID: 28589233; PMCID: PMC5709199.
- Glaser JI, Perich MG, Ramkumar P, Miller LE, Kording KP. Population coding of conditional probability distributions in dorsal premotor cortex. Nat Commun. 2018 May 3;9(1):1788. doi: 10.1038/s41467-018-04062-6. PMID: 29725023; PMCID: PMC5934453.
- Churchland MM, Cunningham JP, Kaufman MT, Foster JD, Nuyujukian P, Ryu SI, Shenoy KV. Neural population dynamics during reaching. Nature. 2012 Jul 5;487(7405):51-6. doi: 10.1038/nature11129. PMID: 22722855; PMCID: PMC3393826.

Subjects:
- Mihili (M)
- Chewie (C)
- Jaco (J)
- Mr.T (T)

Trial outcomes
- R = REWARD
- A = ABORT, target is not shown, go cue is never shown
- F = FAIL
- I = INCOMPLETE
